<?php
/**
 * investon functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package investon
 */
 
/**
 * Define Const for theme Dir
 * @since 1.0.0
 * */
define('INVESTON_ROOT_PATH',get_template_directory());
define('INVESTON_ROOT_URL',get_template_directory_uri());
define('INVESTON_CSS',INVESTON_ROOT_URL .'/assets/css');
define('INVESTON_JS',INVESTON_ROOT_URL .'/assets/js');
define('INVESTON_IMG',INVESTON_ROOT_URL .'/assets/img');
define('INVESTON_INC',INVESTON_ROOT_PATH .'/inc');
define('INVESTON_THEME_STYLESHEETS',INVESTON_INC .'/theme-stylesheets');

/**
 * define theme info
 * @since 1.0.0
 * */
if (is_child_theme()){
	$theme = wp_get_theme();
	$parent_theme = $theme->Template;
	$theme_info = wp_get_theme($parent_theme);
}else{
	$theme_info = wp_get_theme();
}
define('INVESTON_DEV_MODE',true);
$gazania_version = INVESTON_DEV_MODE ? time() : $theme_info->get('Version');
define('INVESTON_NAME',$theme_info->get('Name'));
define('INVESTON_VERSION',$gazania_version);
define('INVESTON_AUTHOR',$theme_info->get('Author'));
define('INVESTON_AUTHOR_URI',$theme_info->get('AuthorURI'));

/*
 * include template helper function
 * @since 1.0.0
 * */
if (file_exists(INVESTON_INC.'/template-functions.php') && INVESTON_INC.'/template-tags.php'){
	require_once  INVESTON_INC.'/template-functions.php';
	require_once  INVESTON_INC.'/template-tags.php';

	function Investon_Function($instance){
		$new_instance = false;
		switch ($instance){
			case ("Functions"):
				$new_instance = class_exists('Investon_Functions') ? Investon_Functions::getInstance() : false;
				break;
			case ("Tags"):
				$new_instance = class_exists('Investon_Tags') ? Investon_Tags::getInstance() : false;
				break;
			default:
				 $new_instance = false;
			break;
		}

		return $new_instance;
	}
}



/*
* Include theme init file
* @since 1.0.0
*/
if ( file_exists(INVESTON_INC.'/class-investon-init.php' ) ) {
	require_once  INVESTON_INC.'/class-investon-init.php';
}

if ( file_exists(INVESTON_INC.'/plugins/tgma/activate.php') ) {
	require_once  INVESTON_INC.'/plugins/tgma/activate.php';
}		

/**
 * Custom template helper function for this theme.
 */
require_once INVESTON_INC . '/template-helper.php';
require_once INVESTON_INC . '/investon_customizer.php';
require_once INVESTON_INC . '/investon_customizer_data.php';



// Move comments textarea to bottom
function gazania_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}
add_filter( 'comment_form_fields', 'gazania_move_comment_field_to_bottom' );


/**
 * Nav menu fallback function
 * @since 1.0.0
 */
 function investon_primary_menu_fallback()
{
    get_template_part('template-parts/default', 'menu');
}


function investon_block_editor_styles() {
	wp_enqueue_style( 'block-editor-bootstrap', get_theme_file_uri( 'assets/css/block-editor.bootstrap.css' ), array(), null );
	wp_enqueue_style( 'block-editor-theme', get_theme_file_uri( 'assets/css/block-editor.theme.css' ), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'investon_block_editor_styles', 1, 1 );

/**
* admin js
**/
add_action('admin_enqueue_scripts', 'investon_admin_custom_scripts');
function investon_admin_custom_scripts(){
	wp_enqueue_media();
	wp_register_script('investon-admin-custom', get_template_directory_uri().'/inc/js/admin_custom.js', array('jquery'), '', true);
	wp_enqueue_script('investon-admin-custom');
}


/**
* shortcode supports for removing extra p, spance etc
*
*/
add_filter( 'the_content', 'investon_shortcode_extra_content_remove' );
/**
 * Filters the content to remove any extra paragraph or break tags
 * caused by shortcodes.
 *
 * @since 1.0.0
 *
 * @param string $content  String of HTML content.
 * @return string $content Amended string of HTML content.
 */
function investon_shortcode_extra_content_remove( $content ) {

    $array = array(
        '<p>['    => '[',
        ']</p>'   => ']',
        ']<br />' => ']'
    );
    return strtr( $content, $array );

}


/**
 * Nav menu fallback function
 * @since 1.0.0
 */
 function investon_theme_fallback_menu()
{
    get_template_part('template-parts/default', 'menu');
}
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328935&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        